### Getting Started

1. Create a virtual environment `python -m venv venv`. 
2. Activate the virtual environment `source venv/bin/activate`. 
3. Install required dependencies `pip install -r requirements.txt`. 

### To run the tests

1. Make sure the virtual environment is activated. 
2. Run `pytest`. 
